// checkmenu.h
//
// This program is free software. See the file COPYING for details.
// Author: Mattias Engdegrd, 1997-1999

#ifndef CHECKMENU_H
#define CHECKMENU_H

#include <qpopupmenu.h>
#include <qpainter.h>

class CheckMenu : public QPopupMenu
{
public:
    CheckMenu(QWidget *parent = 0);

#if QT_VERSION < 200
protected:
    virtual void paintCell(QPainter *p, int row, int col);
#endif
};

#endif	// CHECKMENU_H
